@@ -143,7 +143,7 @@ class MultiprocessDomparserResult():
         for output_html in output_htmls:
             index = index+1
             soup = BeautifulSoup(output_html[0], features="html.parser")
-            body = soup.find('body')
+            body = soup.body
             body_contents = str(body.find_all(recursive=False)[0])
             wrapped_result = f"""
             <li>
